% fig10.m  Run simulations and plot results for Fig. 10 of:
%
%             Bruce, I. C. (2009). "Evaluation of stochastic differential equation
%             approximation of ion channel gating models," Annals of Biomedical
%             Engineering 37(4):824838.
%
% Ian C. Bruce (ibruce@ieee.org)  2009


nrep = 1e3;
Na_max = 1e3;
scaling = 'scaled';

Is = (4.9:0.1:6.5)/0.265; % For Na_max = 1,000

[Ith_cw,RS_cw,FEs_cw,Is_cw]=findIthRS('cw',Is,nrep,Na_max,scaling);
[Ith_fx,RS_fx,FEs_fx,Is_fx]=findIthRS('fx',Is,nrep,Na_max,scaling);
[Ith_fxemp,RS_fxemp,FEs_fxemp,Is_fxemp]=findIthRS('fxemp',Is,nrep,Na_max,scaling);

figure

feplot1=plot(Is_cw,FEs_cw,'r*');
hold on
feplot2=plot(Is_fx,FEs_fx,'bs');
feplot3=plot(Is_fxemp,FEs_fxemp,'g+');
ylabel('FE')
xlabel('I (pA)')
legend([feplot1, feplot2, feplot3],'C&W','F&L theor.','F&L emp.','Location','SouthEast')

% Plot integrated-Gaussian fits to FE versus I results: Eq. (16)
I = linspace(min([Is_cw(1) Is_fx(1) Is_fxemp(1)]),max([Is_cw(end) Is_fx(end) Is_fxemp(end)]),100);
intgauss_cw = 1/2*(erf((I-Ith_cw)/sqrt(2)/(RS_cw*Ith_cw))+1);
intgauss_fx = 1/2*(erf((I-Ith_fx)/sqrt(2)/(RS_fx*Ith_fx))+1);
intgauss_fxemp = 1/2*(erf((I-Ith_fxemp)/sqrt(2)/(RS_fxemp*Ith_fxemp))+1);
plot(I,intgauss_cw,'r-')
plot(I,intgauss_fx,'b-')
plot(I,intgauss_fxemp,'g-')
